RRTMG
---------

.. toctree::
   :maxdepth: 3

  climlab.radiation.rrtm.RRTMG
  climlab.radiation.rrtm.RRTMG_LW
  climlab.radiation.rrtm.RRTMG_SW

.. automodule:: climlab.radiation.rrtm
    :members:
    :private-members:
    :undoc-members:
    :show-inheritance:
